The **python-weka-wrapper3** package makes it easy to run
`Weka <http://www.cs.waikato.ac.nz/~ml/weka/>`_ algorithms and filters from 
within Python 3. It offers access to Weka API using thin wrappers around JNI 
calls using the `javabridge <https://pypi.python.org/pypi/javabridge>`_ package.

Forum for project at:

https://groups.google.com/forum/#!forum/python-weka-wrapper
